import React from "react";
import { render } from "@testing-library/react";
import "@testing-library/jest-dom/extend-expect";
import Table from "./Table";

describe("regarding the Table component", () => {
  it("it should not crash", () => {
    const { getByTestId } = render(
      <Table
        headers={[{ name: "Concept", property: "concept" }]}
        data={[{ concept: "This is a test row" }]}
      />
    );

    expect(getByTestId("table-row-0").textContent).toEqual(
      "This is a test row"
    );
  });

  describe("given a header with a format function", () => {
    it("should execute and render the result of the format function", () => {
      const { getByTestId } = render(
        <Table
          headers={[
            {
              name: "Concept",
              property: "concept",
              tableOptions: {
                format: (item) => {
                  return item.concept + " 1";
                },
              },
            },
          ]}
          data={[{ concept: "This is a test row" }]}
        />
      );

      expect(getByTestId("table-row-0").textContent).toEqual(
        "This is a test row 1"
      );
    });
  });

  describe("given a header with an empty tableOptions prop", () => {
    it("should not crash", () => {
      render(
        <Table
          headers={[
            {
              name: "Concept",
              property: "concept",
              tableOptions: {},
            },
          ]}
          data={[{ concept: "This is a test row" }]}
        />
      );
    });
  });

  describe("given a header without a tableOptions prop", () => {
    it("should not crash", () => {
      render(
        <Table
          headers={[
            {
              name: "Concept",
              property: "concept",
            },
          ]}
          data={[{ concept: "This is a test row" }]}
        />
      );
    });
  });
});
