const chokidar = require("chokidar");
const fs = require("fs");
const fsp = require("fs/promises");
const prettier = require("prettier");

const rootDir = process.cwd() + "/src";
const documentationFile = "documentation.json";
const template = fs.readFileSync(rootDir + "/utils/storybook/template.mdx");

chokidar.watch(`${rootDir}/**/${documentationFile}`).on("change", async () => {
  const documentedComponents = await getDocumentedComponents();

  documentedComponents.forEach((component) => {
    const route = rootDir + "/" + component;
    const documentation = JSON.parse(
      fs.readFileSync(`${route}/${documentationFile}`)
    );

    fsp.writeFile(
      route + "/" + component + ".stories.mdx",
      prettier.format(
        replace(template.toString(), { component, ...documentation }),
        { parser: "mdx" }
      )
    );
  });
});

function getDocumentedComponents() {
  return fsp.readdir(rootDir).then((directories) => {
    return directories.filter(isComponentDirectory).filter(hasDocumentation);
  });
}

function isComponentDirectory(directory) {
  return directory.charAt(0) === directory.charAt(0).toUpperCase();
}

function hasDocumentation(directory) {
  return fs.readdirSync(rootDir + "/" + directory).includes(documentationFile);
}

function replace(text, replaces = {}) {
  return Object.keys(replaces).reduce((reducer, key) => {
    const regex = new RegExp(`\\[${key}\\]`, "g");
    const value = getValue(replaces[key]);

    return reducer.replace(regex, value);
  }, text);
}

function getValue(value) {
  return typeof value === "object" ? JSON.stringify(value) : value;
}
